/****************************************************************************
** Meta object code from reading C++ file 'xychartcore.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kqtquickcharts-17.04.3/src/xychartcore.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xychartcore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_XYChartCore_t {
    QByteArrayData data[20];
    char stringdata0[247];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XYChartCore_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XYChartCore_t qt_meta_stringdata_XYChartCore = {
    {
QT_MOC_LITERAL(0, 0, 11), // "XYChartCore"
QT_MOC_LITERAL(1, 12, 18), // "pointRadiusChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 16), // "lineWidthChanged"
QT_MOC_LITERAL(4, 49, 12), // "xAxisChanged"
QT_MOC_LITERAL(5, 62, 12), // "yAxisChanged"
QT_MOC_LITERAL(6, 75, 16), // "textColorChanged"
QT_MOC_LITERAL(7, 92, 11), // "fontChanged"
QT_MOC_LITERAL(8, 104, 16), // "gridLinesChanged"
QT_MOC_LITERAL(9, 121, 25), // "axisLabelCountGoalChanged"
QT_MOC_LITERAL(10, 147, 10), // "updateAxis"
QT_MOC_LITERAL(11, 158, 11), // "pointRadius"
QT_MOC_LITERAL(12, 170, 9), // "lineWidth"
QT_MOC_LITERAL(13, 180, 5), // "xAxis"
QT_MOC_LITERAL(14, 186, 10), // "Dimension*"
QT_MOC_LITERAL(15, 197, 5), // "yAxis"
QT_MOC_LITERAL(16, 203, 9), // "textColor"
QT_MOC_LITERAL(17, 213, 4), // "font"
QT_MOC_LITERAL(18, 218, 9), // "gridLines"
QT_MOC_LITERAL(19, 228, 18) // "axisLabelCountGoal"

    },
    "XYChartCore\0pointRadiusChanged\0\0"
    "lineWidthChanged\0xAxisChanged\0"
    "yAxisChanged\0textColorChanged\0fontChanged\0"
    "gridLinesChanged\0axisLabelCountGoalChanged\0"
    "updateAxis\0pointRadius\0lineWidth\0xAxis\0"
    "Dimension*\0yAxis\0textColor\0font\0"
    "gridLines\0axisLabelCountGoal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XYChartCore[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       8,   68, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    0,   62,    2, 0x06 /* Public */,
       6,    0,   63,    2, 0x06 /* Public */,
       7,    0,   64,    2, 0x06 /* Public */,
       8,    0,   65,    2, 0x06 /* Public */,
       9,    0,   66,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   67,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
      11, QMetaType::QReal, 0x00495103,
      12, QMetaType::QReal, 0x00495103,
      13, 0x80000000 | 14, 0x0049510b,
      15, 0x80000000 | 14, 0x0049510b,
      16, QMetaType::QColor, 0x00495103,
      17, QMetaType::QFont, 0x00495103,
      18, QMetaType::Bool, 0x00495103,
      19, QMetaType::UInt, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,

       0        // eod
};

void XYChartCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        XYChartCore *_t = static_cast<XYChartCore *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->pointRadiusChanged(); break;
        case 1: _t->lineWidthChanged(); break;
        case 2: _t->xAxisChanged(); break;
        case 3: _t->yAxisChanged(); break;
        case 4: _t->textColorChanged(); break;
        case 5: _t->fontChanged(); break;
        case 6: _t->gridLinesChanged(); break;
        case 7: _t->axisLabelCountGoalChanged(); break;
        case 8: _t->updateAxis(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::pointRadiusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::lineWidthChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::xAxisChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::yAxisChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::textColorChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::fontChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::gridLinesChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (XYChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartCore::axisLabelCountGoalChanged)) {
                *result = 7;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dimension* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        XYChartCore *_t = static_cast<XYChartCore *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->pointRadius(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->lineWidth(); break;
        case 2: *reinterpret_cast< Dimension**>(_v) = _t->xAxis(); break;
        case 3: *reinterpret_cast< Dimension**>(_v) = _t->yAxis(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->textColor(); break;
        case 5: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->gridLines(); break;
        case 7: *reinterpret_cast< uint*>(_v) = _t->axisLabelCountGoal(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        XYChartCore *_t = static_cast<XYChartCore *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPointRadius(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setLineWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setXAxis(*reinterpret_cast< Dimension**>(_v)); break;
        case 3: _t->setYAxis(*reinterpret_cast< Dimension**>(_v)); break;
        case 4: _t->setTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 5: _t->setFont(*reinterpret_cast< QFont*>(_v)); break;
        case 6: _t->setGridLines(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setAxisLabelCountGoal(*reinterpret_cast< uint*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject XYChartCore::staticMetaObject = {
    { &ChartCore::staticMetaObject, qt_meta_stringdata_XYChartCore.data,
      qt_meta_data_XYChartCore,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XYChartCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYChartCore::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XYChartCore.stringdata0))
        return static_cast<void*>(const_cast< XYChartCore*>(this));
    return ChartCore::qt_metacast(_clname);
}

int XYChartCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChartCore::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void XYChartCore::pointRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void XYChartCore::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void XYChartCore::xAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void XYChartCore::yAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void XYChartCore::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void XYChartCore::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void XYChartCore::gridLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void XYChartCore::axisLabelCountGoalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
