/****************************************************************************
** Meta object code from reading C++ file 'xychartpainter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kqtquickcharts-17.04.3/src/xychartpainter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xychartpainter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_XYChartPainter_t {
    QByteArrayData data[11];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XYChartPainter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XYChartPainter_t qt_meta_stringdata_XYChartPainter = {
    {
QT_MOC_LITERAL(0, 0, 14), // "XYChartPainter"
QT_MOC_LITERAL(1, 15, 18), // "xyChartCoreChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 24), // "backgroundPainterChanged"
QT_MOC_LITERAL(4, 60, 16), // "dimensionChanged"
QT_MOC_LITERAL(5, 77, 13), // "triggerUpdate"
QT_MOC_LITERAL(6, 91, 11), // "xyChartCore"
QT_MOC_LITERAL(7, 103, 12), // "XYChartCore*"
QT_MOC_LITERAL(8, 116, 17), // "backgroundPainter"
QT_MOC_LITERAL(9, 134, 25), // "XYChartBackgroundPainter*"
QT_MOC_LITERAL(10, 160, 9) // "dimension"

    },
    "XYChartPainter\0xyChartCoreChanged\0\0"
    "backgroundPainterChanged\0dimensionChanged\0"
    "triggerUpdate\0xyChartCore\0XYChartCore*\0"
    "backgroundPainter\0XYChartBackgroundPainter*\0"
    "dimension"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XYChartPainter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       3,   38, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    0,   35,    2, 0x06 /* Public */,
       4,    0,   36,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   37,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
       6, 0x80000000 | 7, 0x0049500b,
       8, 0x80000000 | 9, 0x0049510b,
      10, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,

       0        // eod
};

void XYChartPainter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        XYChartPainter *_t = static_cast<XYChartPainter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->xyChartCoreChanged(); break;
        case 1: _t->backgroundPainterChanged(); break;
        case 2: _t->dimensionChanged(); break;
        case 3: _t->triggerUpdate(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (XYChartPainter::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartPainter::xyChartCoreChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (XYChartPainter::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartPainter::backgroundPainterChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (XYChartPainter::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&XYChartPainter::dimensionChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        XYChartPainter *_t = static_cast<XYChartPainter *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< XYChartCore**>(_v) = _t->xyChartCore(); break;
        case 1: *reinterpret_cast< XYChartBackgroundPainter**>(_v) = _t->backgroundPainter(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->dimension(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        XYChartPainter *_t = static_cast<XYChartPainter *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setXYChartCore(*reinterpret_cast< XYChartCore**>(_v)); break;
        case 1: _t->setBackgroundPainter(*reinterpret_cast< XYChartBackgroundPainter**>(_v)); break;
        case 2: _t->setDimension(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_a);
}

const QMetaObject XYChartPainter::staticMetaObject = {
    { &QQuickPaintedItem::staticMetaObject, qt_meta_stringdata_XYChartPainter.data,
      qt_meta_data_XYChartPainter,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XYChartPainter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYChartPainter::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XYChartPainter.stringdata0))
        return static_cast<void*>(const_cast< XYChartPainter*>(this));
    return QQuickPaintedItem::qt_metacast(_clname);
}

int XYChartPainter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void XYChartPainter::xyChartCoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void XYChartPainter::backgroundPainterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void XYChartPainter::dimensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
