/****************************************************************************
** Meta object code from reading C++ file 'chartmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kqtquickcharts-17.04.3/src/chartmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chartmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ChartModel_t {
    QByteArrayData data[20];
    char stringdata0[211];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChartModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChartModel_t qt_meta_stringdata_ChartModel = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ChartModel"
QT_MOC_LITERAL(1, 11, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 27, 7), // "records"
QT_MOC_LITERAL(3, 35, 14), // "columnsChanged"
QT_MOC_LITERAL(4, 50, 0), // ""
QT_MOC_LITERAL(5, 51, 11), // "rowsChanged"
QT_MOC_LITERAL(6, 63, 13), // "recordChanged"
QT_MOC_LITERAL(7, 77, 3), // "row"
QT_MOC_LITERAL(8, 81, 15), // "onRecordChanged"
QT_MOC_LITERAL(9, 97, 7), // "Record*"
QT_MOC_LITERAL(10, 105, 6), // "record"
QT_MOC_LITERAL(11, 112, 12), // "appendRecord"
QT_MOC_LITERAL(12, 125, 12), // "insertRecord"
QT_MOC_LITERAL(13, 138, 12), // "removeRecord"
QT_MOC_LITERAL(14, 151, 5), // "value"
QT_MOC_LITERAL(15, 157, 6), // "column"
QT_MOC_LITERAL(16, 164, 8), // "setValue"
QT_MOC_LITERAL(17, 173, 24), // "QQmlListProperty<Record>"
QT_MOC_LITERAL(18, 198, 7), // "columns"
QT_MOC_LITERAL(19, 206, 4) // "rows"

    },
    "ChartModel\0DefaultProperty\0records\0"
    "columnsChanged\0\0rowsChanged\0recordChanged\0"
    "row\0onRecordChanged\0Record*\0record\0"
    "appendRecord\0insertRecord\0removeRecord\0"
    "value\0column\0setValue\0QQmlListProperty<Record>\0"
    "columns\0rows"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChartModel[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       9,   16, // methods
       3,   88, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   61,    4, 0x06 /* Public */,
       5,    0,   62,    4, 0x06 /* Public */,
       6,    1,   63,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   66,    4, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      11,    0,   69,    4, 0x02 /* Public */,
      12,    1,   70,    4, 0x02 /* Public */,
      13,    1,   73,    4, 0x02 /* Public */,
      14,    2,   76,    4, 0x02 /* Public */,
      16,    3,   81,    4, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    7,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9,   10,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::QReal, QMetaType::Int, QMetaType::Int,    7,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QReal,    7,   15,   14,

 // properties: name, type, flags
       2, 0x80000000 | 17, 0x00095409,
      18, QMetaType::Int, 0x00495103,
      19, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       1,

       0        // eod
};

void ChartModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChartModel *_t = static_cast<ChartModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->columnsChanged(); break;
        case 1: _t->rowsChanged(); break;
        case 2: _t->recordChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->onRecordChanged((*reinterpret_cast< Record*(*)>(_a[1]))); break;
        case 4: _t->appendRecord(); break;
        case 5: _t->insertRecord((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->removeRecord((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: { qreal _r = _t->value((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< qreal*>(_a[0]) = _r; }  break;
        case 8: _t->setValue((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ChartModel::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartModel::columnsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ChartModel::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartModel::rowsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ChartModel::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartModel::recordChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        ChartModel *_t = static_cast<ChartModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQmlListProperty<Record>*>(_v) = _t->records(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->columns(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->rows(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        ChartModel *_t = static_cast<ChartModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setColumns(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject ChartModel::staticMetaObject = {
    { &QAbstractTableModel::staticMetaObject, qt_meta_stringdata_ChartModel.data,
      qt_meta_data_ChartModel,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ChartModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChartModel::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ChartModel.stringdata0))
        return static_cast<void*>(const_cast< ChartModel*>(this));
    return QAbstractTableModel::qt_metacast(_clname);
}

int ChartModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ChartModel::columnsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void ChartModel::rowsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void ChartModel::recordChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_END_MOC_NAMESPACE
