/****************************************************************************
** Meta object code from reading C++ file 'dimension.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kqtquickcharts-17.04.3/src/dimension.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dimension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Dimension_t {
    QByteArrayData data[33];
    char stringdata0[416];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dimension_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dimension_t qt_meta_stringdata_Dimension = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Dimension"
QT_MOC_LITERAL(1, 10, 12), // "colorChanged"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 17), // "dataColumnChanged"
QT_MOC_LITERAL(4, 42, 19), // "minimumValueChanged"
QT_MOC_LITERAL(5, 62, 19), // "maximumValueChanged"
QT_MOC_LITERAL(6, 82, 12), // "labelChanged"
QT_MOC_LITERAL(7, 95, 16), // "precisionChanged"
QT_MOC_LITERAL(8, 112, 11), // "unitChanged"
QT_MOC_LITERAL(9, 124, 17), // "unitFactorChanged"
QT_MOC_LITERAL(10, 142, 7), // "updated"
QT_MOC_LITERAL(11, 150, 18), // "markerStyleChanged"
QT_MOC_LITERAL(12, 169, 16), // "lineStyleChanged"
QT_MOC_LITERAL(13, 186, 11), // "formatValue"
QT_MOC_LITERAL(14, 198, 5), // "value"
QT_MOC_LITERAL(15, 204, 5), // "color"
QT_MOC_LITERAL(16, 210, 10), // "dataColumn"
QT_MOC_LITERAL(17, 221, 12), // "minimumValue"
QT_MOC_LITERAL(18, 234, 12), // "maximumValue"
QT_MOC_LITERAL(19, 247, 5), // "label"
QT_MOC_LITERAL(20, 253, 9), // "precision"
QT_MOC_LITERAL(21, 263, 4), // "unit"
QT_MOC_LITERAL(22, 268, 10), // "unitFactor"
QT_MOC_LITERAL(23, 279, 11), // "markerStyle"
QT_MOC_LITERAL(24, 291, 11), // "MarkerStyle"
QT_MOC_LITERAL(25, 303, 9), // "lineStyle"
QT_MOC_LITERAL(26, 313, 9), // "LineStyle"
QT_MOC_LITERAL(27, 323, 15), // "MarkerStyleNone"
QT_MOC_LITERAL(28, 339, 16), // "MarkerStyleRound"
QT_MOC_LITERAL(29, 356, 16), // "MarkerStyleCross"
QT_MOC_LITERAL(30, 373, 13), // "LineStyleNone"
QT_MOC_LITERAL(31, 387, 14), // "LineStyleSolid"
QT_MOC_LITERAL(32, 402, 13) // "LineStyleDash"

    },
    "Dimension\0colorChanged\0\0dataColumnChanged\0"
    "minimumValueChanged\0maximumValueChanged\0"
    "labelChanged\0precisionChanged\0unitChanged\0"
    "unitFactorChanged\0updated\0markerStyleChanged\0"
    "lineStyleChanged\0formatValue\0value\0"
    "color\0dataColumn\0minimumValue\0"
    "maximumValue\0label\0precision\0unit\0"
    "unitFactor\0markerStyle\0MarkerStyle\0"
    "lineStyle\0LineStyle\0MarkerStyleNone\0"
    "MarkerStyleRound\0MarkerStyleCross\0"
    "LineStyleNone\0LineStyleSolid\0LineStyleDash"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dimension[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
      10,   88, // properties
       2,  128, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    0,   76,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    0,   78,    2, 0x06 /* Public */,
       7,    0,   79,    2, 0x06 /* Public */,
       8,    0,   80,    2, 0x06 /* Public */,
       9,    0,   81,    2, 0x06 /* Public */,
      10,    0,   82,    2, 0x06 /* Public */,
      11,    0,   83,    2, 0x06 /* Public */,
      12,    0,   84,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      13,    1,   85,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::QString, QMetaType::QReal,   14,

 // properties: name, type, flags
      15, QMetaType::QColor, 0x00495103,
      16, QMetaType::Int, 0x00495103,
      17, QMetaType::QReal, 0x00495103,
      18, QMetaType::QReal, 0x00495103,
      19, QMetaType::QString, 0x00495103,
      20, QMetaType::Int, 0x00495103,
      21, QMetaType::QString, 0x00495103,
      22, QMetaType::QReal, 0x00495103,
      23, 0x80000000 | 24, 0x0049510b,
      25, 0x80000000 | 26, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       9,
      10,

 // enums: name, flags, count, data
      24, 0x0,    3,  136,
      26, 0x0,    3,  142,

 // enum data: key, value
      27, uint(Dimension::MarkerStyleNone),
      28, uint(Dimension::MarkerStyleRound),
      29, uint(Dimension::MarkerStyleCross),
      30, uint(Dimension::LineStyleNone),
      31, uint(Dimension::LineStyleSolid),
      32, uint(Dimension::LineStyleDash),

       0        // eod
};

void Dimension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Dimension *_t = static_cast<Dimension *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorChanged(); break;
        case 1: _t->dataColumnChanged(); break;
        case 2: _t->minimumValueChanged(); break;
        case 3: _t->maximumValueChanged(); break;
        case 4: _t->labelChanged(); break;
        case 5: _t->precisionChanged(); break;
        case 6: _t->unitChanged(); break;
        case 7: _t->unitFactorChanged(); break;
        case 8: _t->updated(); break;
        case 9: _t->markerStyleChanged(); break;
        case 10: _t->lineStyleChanged(); break;
        case 11: { QString _r = _t->formatValue((*reinterpret_cast< qreal(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::colorChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::dataColumnChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::minimumValueChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::maximumValueChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::labelChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::precisionChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::unitChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::unitFactorChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::updated)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::markerStyleChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Dimension::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dimension::lineStyleChanged)) {
                *result = 10;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        Dimension *_t = static_cast<Dimension *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->dataColumn(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->minimumValue(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->maximumValue(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->precision(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->unit(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->unitFactor(); break;
        case 8: *reinterpret_cast< MarkerStyle*>(_v) = _t->markerStyle(); break;
        case 9: *reinterpret_cast< LineStyle*>(_v) = _t->lineStyle(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        Dimension *_t = static_cast<Dimension *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 1: _t->setDataColumn(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setMinimumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setMaximumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setPrecision(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setUnit(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setUnitFactor(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setMarkerStyle(*reinterpret_cast< MarkerStyle*>(_v)); break;
        case 9: _t->setLineStyle(*reinterpret_cast< LineStyle*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Dimension::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Dimension.data,
      qt_meta_data_Dimension,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Dimension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dimension::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Dimension.stringdata0))
        return static_cast<void*>(const_cast< Dimension*>(this));
    return QObject::qt_metacast(_clname);
}

int Dimension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dimension::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void Dimension::dataColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void Dimension::minimumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void Dimension::maximumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void Dimension::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void Dimension::precisionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void Dimension::unitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void Dimension::unitFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, Q_NULLPTR);
}

// SIGNAL 8
void Dimension::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 8, Q_NULLPTR);
}

// SIGNAL 9
void Dimension::markerStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, Q_NULLPTR);
}

// SIGNAL 10
void Dimension::lineStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
