/****************************************************************************
** Meta object code from reading C++ file 'chartcore.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kqtquickcharts-17.04.3/src/chartcore.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chartcore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ChartCore_t {
    QByteArrayData data[14];
    char stringdata0[174];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChartCore_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChartCore_t qt_meta_stringdata_ChartCore = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ChartCore"
QT_MOC_LITERAL(1, 10, 12), // "modelChanged"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 17), // "chartStyleChanged"
QT_MOC_LITERAL(4, 42, 12), // "pitchChanged"
QT_MOC_LITERAL(5, 55, 15), // "textRoleChanged"
QT_MOC_LITERAL(6, 71, 7), // "updated"
QT_MOC_LITERAL(7, 79, 13), // "triggerUpdate"
QT_MOC_LITERAL(8, 93, 5), // "model"
QT_MOC_LITERAL(9, 99, 20), // "QAbstractTableModel*"
QT_MOC_LITERAL(10, 120, 10), // "dimensions"
QT_MOC_LITERAL(11, 131, 27), // "QQmlListProperty<Dimension>"
QT_MOC_LITERAL(12, 159, 5), // "pitch"
QT_MOC_LITERAL(13, 165, 8) // "textRole"

    },
    "ChartCore\0modelChanged\0\0chartStyleChanged\0"
    "pitchChanged\0textRoleChanged\0updated\0"
    "triggerUpdate\0model\0QAbstractTableModel*\0"
    "dimensions\0QQmlListProperty<Dimension>\0"
    "pitch\0textRole"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChartCore[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       4,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   49,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
       8, 0x80000000 | 9, 0x0049510b,
      10, 0x80000000 | 11, 0x00095409,
      12, QMetaType::QReal, 0x00495103,
      13, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       2,
       3,

       0        // eod
};

void ChartCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChartCore *_t = static_cast<ChartCore *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->chartStyleChanged(); break;
        case 2: _t->pitchChanged(); break;
        case 3: _t->textRoleChanged(); break;
        case 4: _t->updated(); break;
        case 5: _t->triggerUpdate(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartCore::modelChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartCore::chartStyleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartCore::pitchChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartCore::textRoleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ChartCore::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ChartCore::updated)) {
                *result = 4;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        ChartCore *_t = static_cast<ChartCore *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QAbstractTableModel**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast< QQmlListProperty<Dimension>*>(_v) = _t->dimensions(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->pitch(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->textRole(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        ChartCore *_t = static_cast<ChartCore *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast< QAbstractTableModel**>(_v)); break;
        case 2: _t->setPitch(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setTextRole(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_a);
}

const QMetaObject ChartCore::staticMetaObject = {
    { &QQuickPaintedItem::staticMetaObject, qt_meta_stringdata_ChartCore.data,
      qt_meta_data_ChartCore,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ChartCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChartCore::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ChartCore.stringdata0))
        return static_cast<void*>(const_cast< ChartCore*>(this));
    return QQuickPaintedItem::qt_metacast(_clname);
}

int ChartCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ChartCore::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void ChartCore::chartStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void ChartCore::pitchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void ChartCore::textRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void ChartCore::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
